@@ -1,4 +1,4 @@
-use tch::{Device, Kind, Tensor};
+use tch::{Device, Kind, Reduction, Tensor};
 
 #[derive(Debug, serde::Serialize, serde::Deserialize)]
 struct Example {
@@ -8,6 +8,8 @@ struct Example {
     kind: Kind,
     #[serde(with = "tch_serde::serde_device")]
     device: Device,
+    #[serde(with = "tch_serde::serde_reduction")]
+    reduction: Reduction,
 }
 
 fn main() {
@@ -15,6 +17,7 @@ fn main() {
         tensor: Tensor::randn(&[2, 3], (Kind::Float, Device::cuda_if_available())),
         kind: Kind::Float,
         device: Device::Cpu,
+        reduction: Reduction::Mean,
     };
     let text = serde_json::to_string_pretty(&example).unwrap();
     println!("{}", text);
